hyperspy\.samfire\_utils package
================================

Subpackages
-----------

.. toctree::

    hyperspy.samfire_utils.goodness_of_fit_tests
    hyperspy.samfire_utils.segmenters
    hyperspy.samfire_utils.weights

Submodules
----------

hyperspy\.samfire\_utils\.fit\_tests module
-------------------------------------------

.. automodule:: hyperspy.samfire_utils.fit_tests
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.global\_strategies module
---------------------------------------------------

.. automodule:: hyperspy.samfire_utils.global_strategies
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.local\_strategies module
--------------------------------------------------

.. automodule:: hyperspy.samfire_utils.local_strategies
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.samfire\_kernel module
------------------------------------------------

.. automodule:: hyperspy.samfire_utils.samfire_kernel
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.samfire\_pool module
----------------------------------------------

.. automodule:: hyperspy.samfire_utils.samfire_pool
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.samfire\_worker module
------------------------------------------------

.. automodule:: hyperspy.samfire_utils.samfire_worker
    :members:
    :undoc-members:
    :show-inheritance:

hyperspy\.samfire\_utils\.strategy module
-----------------------------------------

.. automodule:: hyperspy.samfire_utils.strategy
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: hyperspy.samfire_utils
    :members:
    :undoc-members:
    :show-inheritance:
